| Title: | On-Disk support and dependancies for VoltRon |
|---|---|
| Description: | VoltRonStore provides utilities and a resource for installing dependencies of VoltRon package |
| Authors: | Art<c3><bc>r Manukyan, Markus Landthaler, Altuna Akalin |
| Maintainer: | Art<c3><bc>r Manukyan <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-06-01 06:54:07 UTC |
| Source: | https://github.com/Artur-man/VoltRonStore |
VoltRonStore provides utilities and a resource for installing dependencies of VoltRon package
Artür Manukyan, Markus Landthaler, Altuna Akalin
Maintainer: Artür Manukyan <[email protected]>